@@ -10,7 +10,6 @@
 #include <QJsonArray>
 #include <QJsonObject>
 #include <QSharedData>
-#include <QVector>
 
 using namespace KUserFeedback::Console;
 
@@ -94,3 +93,5 @@ QVector<SchemaEntryElement> SchemaEntryElement::fromJson(const QJsonArray& array
 
     return res;
 }
+
+#include "moc_schemaentryelement.cpp"
